from setuptools import setup

setup(name='distributionsBG',
      version='2.1',
      description='Gaussian and Binomial distributions',
      packages=['distributionsBG'],
      author = 'Svitlana Konopatska',
      author_email = 'svetlana_viktorovna@meta.ua',
      zip_safe=False)
